@@ -7,4 +7,7 @@ if not (2, 7) <= sys.version_info < (3,):
         'Leapcast requires Python >= 2.7, < 3, but found %s' %
         '.'.join(map(str, sys.version_info[:3])))
 
-__version__ = '0.0.8'
+__version__ = '0.0.9'
+__url__ = 'https://github.com/dz0ny/leapcast'
+__author__ = 'Janez Troha'
+__email__ = 'dz0ny@ubuntu.si'
